@@ -90,10 +90,11 @@ screenhack_usleep (usecs)
      unsigned long usecs;
 {
   int status, *bin_delta;
-  extern int SYS$SCHWDK (), SYS$HIBER (); 
+  extern int SYS$SCHDWK (), SYS$HIBER (); 
   
   if (!deltas_set) set_deltas ();
-  bin_delta = (usecs == TICK_INTERVAL) ? &bin_tick_delta : &bin_sec_delta;
+  bin_delta = (int *)((usecs == TICK_INTERVAL) ? &bin_tick_delta :
+                                               &bin_sec_delta);
   status = SYS$SCHDWK (0, 0, bin_delta, 0);
   if ((status & 1)) (void) SYS$HIBER ();
 }
