@@ -1,6 +1,6 @@
 char *version = "@(#)\
-XDaliClock v2.06; \
-Copyright (c) 1991, 1992, 1993, 1994, 1995 Jamie Zawinski (jwz@netscape.com)";
+XDaliClock v2.07; \
+Copyright (c) 1991,1992,1993,1994,1995,1996 Jamie Zawinski (jwz@netscape.com)";
 
 /*   7 oct 91 (v1.00)	submitted for X11r5 contrib tape.
     26 oct 91 (v1.01)	fixed Expose handling in -noseconds mode;
@@ -33,4 +33,6 @@ Copyright (c) 1991, 1992, 1993, 1994, 1995 Jamie Zawinski (jwz@netscape.com)";
 			visual and cmap.
     24-Dec-95 (v2.06)	Made -cycle work on non-PseudoColor visuals.
 			Fixed a couple of shape-related bugs.
+    23-Feb-96 (v2.07)	Added WM_COMMAND property for session management.
+			More better VMS support from Martin Zinser.
  */
